# {{ package_title}}

> {{ package_tagline }}

[![Latest Version on PyPI](https://img.shields.io/pypi/v/{{package_name}}.svg)](https://pypi.python.org/pypi/{{package_name}}/)
[![Supported Implementations](https://img.shields.io/pypi/pyversions/{{package_name}}.svg)](https://pypi.python.org/pypi/{{package_name}}/)
[![Build Status](https://secure.travis-ci.org/{{github_account}}/{{github_repo_name}}.svg?branch=master)](http://travis-ci.org/christophevg/{{github_repo_name}})
[![Documentation Status](https://readthedocs.org/projects/{{package_name}}/badge/?version=latest)](https://{{package_name}}.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/{{github_account}}/{{github_repo_name}}/badge.svg?branch=master)](https://coveralls.io/github/{{github_account}}/{{github_repo_name}}?branch=master)
[![Built with PyPi Template](https://img.shields.io/badge/PyPi_Template-v{{pypi_template_version}}-blue.svg)](https://github.com/christophevg/pypi-template)

{% block content %}{% endblock %}
